pub fn get_connection_pool() -> Pool<ConnectionManager<SqliteConnection>>Expand description
Get a clone of the shared connection pool. Useful when you need to pass the pool to a different context.
pub fn get_connection_pool() -> Pool<ConnectionManager<SqliteConnection>>Get a clone of the shared connection pool. Useful when you need to pass the pool to a different context.