pub fn set_session_user(session: &Session, user: &SessionUser)Expand description
Cache identity in the session after a successful sign-in or profile change.
pub fn set_session_user(session: &Session, user: &SessionUser)Cache identity in the session after a successful sign-in or profile change.