Module helpers

Module helpers 

Modules

access_log
Build Identity values from Actix requests and run an AccessLogger call with the appropriate failure policy for the resource’s Sensitivity.
audit_context
Build a CommandContext from an Actix HTTP request.
config
csrf
database
es_stack
Shared assembly of the event-sourced stack — EventStore, in-process EventBus, ReadModelStore, ProjectionEngine, and CommandBus.
general
jwt
rate_limit
session
Cookie-session-backed identity for the server-rendered admin UI.
template