Module database

Module database 

Constants

MIGRATIONSDeprecated
Compatibility migration set for framework consumers.

Functions

get_connection
Get a database connection from the shared connection pool. The pool is created lazily on first call and reused for subsequent calls. If the DATABASE_URL changes (e.g., between test runs), the pool is recreated.
get_connection_pool
Get a clone of the shared connection pool. Useful when you need to pass the pool to a different context.