pub fn get_connection() -> PooledConnection<ConnectionManager<SqliteConnection>>Expand description
Get a database connection from the shared connection pool.
The pool is created lazily on first call and reused for subsequent calls.
If the DATABASE_URL changes (e.g., between test runs), the pool is recreated.